Module action

Module action 

SuperTable Actions

This module provides high-level table maintenance actions such as snapshot expiration and orphan file removal.

Structs

ExpireSnapshots
Action to expire old snapshots based on retention policies.
RemoveOrphanFiles
Action to delete files that are no longer referenced by any snapshot.