pub struct ManifestFileEntry {Show 13 fields
pub manifest_path: String,
pub manifest_length: i64,
pub partition_spec_id: i32,
pub content: ManifestContent,
pub sequence_number: i64,
pub min_sequence_number: i64,
pub added_snapshot_id: i64,
pub added_files_count: i64,
pub existing_files_count: i64,
pub deleted_files_count: i64,
pub added_rows_count: i64,
pub existing_rows_count: i64,
pub deleted_rows_count: i64,
}Expand description
An entry in a manifest list, referencing a single manifest file.
Fields
manifest_path: StringPath to the manifest file.
manifest_length: i64Length of the manifest file in bytes.
partition_spec_id: i32The partition spec ID used to write the manifest.
content: ManifestContentThe content type of files in this manifest.
sequence_number: i64Sequence number when this manifest was added.
min_sequence_number: i64Minimum sequence number of any file in this manifest.
added_snapshot_id: i64The snapshot ID that added this manifest.
added_files_count: i64Number of files added in this manifest.
existing_files_count: i64Number of existing (unchanged) files in this manifest.
deleted_files_count: i64Number of files deleted in this manifest.
added_rows_count: i64Number of rows added across all files in this manifest.
existing_rows_count: i64Number of existing rows in this manifest.
deleted_rows_count: i64Number of rows deleted in this manifest.