pub struct MergeBuilder { /* private fields */ }Expand description
Builder for MERGE (UPSERT) operations.
Implementations
Sourceimpl MergeBuilder
impl MergeBuilder
pub fn new( table: Table, source: BoxStream<'static, Result<RecordBatch>>, on_condition: Expr, ) -> Self
Sourcepub fn when_matched(self, condition: Option<Expr>, action: MergeAction) -> Self
pub fn when_matched(self, condition: Option<Expr>, action: MergeAction) -> Self
Adds a clause to be applied when the ON condition matches.
Sourcepub fn when_not_matched(
self,
condition: Option<Expr>,
action: MergeAction,
) -> Self
pub fn when_not_matched( self, condition: Option<Expr>, action: MergeAction, ) -> Self
Adds a clause to be applied when the ON condition does NOT match.
Sourcepub async fn execute(self) -> Result<Transaction>
pub async fn execute(self) -> Result<Transaction>
Executes the merge operation as a Copy-on-Write process.