pub struct PartitionSpec {
pub spec_id: i32,
pub fields: Vec<PartitionField>,
}Expand description
A partition spec defines how a table is partitioned.
Use PartitionSpec::builder() to create new specs.
Fields
spec_id: i32Unique identifier for this partition spec.
fields: Vec<PartitionField>The list of fields that make up the partition tuple.
Implementations
Sourceimpl PartitionSpec
impl PartitionSpec
pub fn builder(schema: &Schema) -> PartitionSpecBuilder<'_>
Sourcepub fn is_unpartitioned(&self) -> bool
pub fn is_unpartitioned(&self) -> bool
Returns true if the table is unpartitioned.