Module scan
supertable_
core
0.1.0
Module scan
Module Items
Structs
Enums
In crate supertable_
core
supertable_core
Module
scan
Structs

Scan
Planner
Plan scans for a table snapshot.
Scan
Task
A single unit of work for reading a table. Combines a data file with its relevant delete files.
Enums

Predicate
A simple predicate for data pruning.