pub struct ScanTask {
pub data_file: DataFile,
pub delete_files: Vec<DataFile>,
}Expand description
A single unit of work for reading a table. Combines a data file with its relevant delete files.
Fields
data_file: DataFiledelete_files: Vec<DataFile>Trait Implementations