pub struct SchemaUpdate { /* private fields */ }Expand description
A pending schema update that can be applied to a schema to produce a new version.
Implementations
Sourceimpl SchemaUpdate
impl SchemaUpdate
pub fn new() -> Self
Sourcepub fn add_column(
self,
parent_id: Option<i32>,
name: impl Into<String>,
field_type: Type,
doc: Option<String>,
) -> Self
pub fn add_column( self, parent_id: Option<i32>, name: impl Into<String>, field_type: Type, doc: Option<String>, ) -> Self
adds a new column to the schema.
Sourcepub fn delete_column(self, field_id: i32) -> Self
pub fn delete_column(self, field_id: i32) -> Self
Deletes a column from the schema.
Sourcepub fn rename_column(self, field_id: i32, new_name: impl Into<String>) -> Self
pub fn rename_column(self, field_id: i32, new_name: impl Into<String>) -> Self
Renames a column.
Sourcepub fn update_type(self, field_id: i32, new_type: Type) -> Self
pub fn update_type(self, field_id: i32, new_type: Type) -> Self
Updates a column’s type (must be compatible).
Sourcepub fn make_optional(self, field_id: i32) -> Self
pub fn make_optional(self, field_id: i32) -> Self
Makes a required column optional.
Sourcepub fn apply(
self,
base_schema: &Schema,
new_schema_id: i32,
next_column_id: &mut i32,
) -> Result<Schema, String>
pub fn apply( self, base_schema: &Schema, new_schema_id: i32, next_column_id: &mut i32, ) -> Result<Schema, String>
Applies the changes to a base schema, producing a new schema.
Arguments
base_schema- The schema to start fromnew_schema_id- The ID for the new schemanext_column_id- A mutable reference to the next available column ID setter