pub struct Table { /* private fields */ }Expand description
A high-level representation of a SuperTable.
Implementations
Sourceimpl Table
impl Table
Sourcepub fn new(
identifier: impl Into<String>,
catalog: Arc<dyn Catalog>,
metadata: TableMetadata,
storage: Storage,
) -> Self
pub fn new( identifier: impl Into<String>, catalog: Arc<dyn Catalog>, metadata: TableMetadata, storage: Storage, ) -> Self
Creates a new table instance.
Sourcepub fn metadata(&self) -> &TableMetadata
pub fn metadata(&self) -> &TableMetadata
Returns the table metadata.
Sourcepub fn identifier(&self) -> &str
pub fn identifier(&self) -> &str
Returns the table identifier.
Sourcepub fn new_transaction(&self) -> Transaction
pub fn new_transaction(&self) -> Transaction
Starts a new transaction on this table.
Sourcepub fn at_snapshot(&self, snapshot_id: i64) -> Result<Table>
pub fn at_snapshot(&self, snapshot_id: i64) -> Result<Table>
Returns a view of the table at a specific snapshot.
Sourcepub fn as_of(&self, timestamp_ms: i64) -> Result<Table>
pub fn as_of(&self, timestamp_ms: i64) -> Result<Table>
Returns a view of the table as of a specific timestamp.
Sourcepub fn new_scan(&self) -> ScanPlanner<'_>
pub fn new_scan(&self) -> ScanPlanner<'_>
Creates a new scan planner for this table’s current snapshot.